Language class final

Constructors

Language({required String name, required String code, required int translations, required double percentage, required String updated})
const
Language.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
percentage double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translations int
final
updated String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited